@@ -6,11 +6,9 @@
 ## library(circlize)
 ## factors = letters[1]
 ## par(mar = c(1, 1, 1, 1))
-## circos.par("gap.degree" = 0, "cell.padding" = c(0, 0, 0, 0),
-##     "start.degree" = 90)
+## circos.par("gap.degree" = 0, "cell.padding" = c(0, 0, 0, 0), "start.degree" = 90)
 ## circos.initialize(factors = factors, xlim = c(0, 12))
-## circos.trackPlotRegion(factors = factors, ylim = c(0, 1),
-##     bg.border = NA)
+## circos.trackPlotRegion(factors = factors, ylim = c(0, 1), bg.border = NA)
 ## circos.axis(sector.index = "a", major.at = 0:12, labels = "",
 ##     direction = "inside", labels.cex = 1.5, major.tick.percentage = 0.3)
 ## circos.text(1:12, rep(0.5, 12), 1:12, direction = "horizontal")
@@ -26,11 +24,9 @@
 library(circlize)
 factors = letters[1]
 par(mar = c(1, 1, 1, 1))
-circos.par("gap.degree" = 0, "cell.padding" = c(0, 0, 0, 0),
-    "start.degree" = 90)
+circos.par("gap.degree" = 0, "cell.padding" = c(0, 0, 0, 0), "start.degree" = 90)
 circos.initialize(factors = factors, xlim = c(0, 12))
-circos.trackPlotRegion(factors = factors, ylim = c(0, 1),
-    bg.border = NA)
+circos.trackPlotRegion(factors = factors, ylim = c(0, 1), bg.border = NA)
 circos.axis(sector.index = "a", major.at = 0:12, labels = "",
     direction = "inside", labels.cex = 1.5, major.tick.percentage = 0.3)
 circos.text(1:12, rep(0.5, 12), 1:12, direction = "horizontal")
@@ -49,18 +45,17 @@ circos.clear()
 ## circos.par("gap.degree" = 0, "cell.padding" = c(0, 0, 0, 0),
 ##     start.degree = 360/40, track.margin = c(0, 0), "clock.wise" = FALSE)
 ## circos.initialize(factors = factors, xlim = c(0, 1))
-## circos.trackPlotRegion(ylim = c(0, 1), factors = factors,
-##     bg.col = "black", track.height = 0.15)
+## circos.trackPlotRegion(ylim = c(0, 1), factors = factors, bg.col = "black",
+##     track.height = 0.15)
 ## circos.trackText(rep(0.5, 20), rep(0.5, 20),
-##     labels = c(13, 4, 18, 1, 20, 5, 12, 9, 14, 11,
-##         8, 16, 7, 19, 3, 17, 2, 15, 10, 6),
+##     labels = c(13, 4, 18, 1, 20, 5, 12, 9, 14, 11, 8, 16, 7, 19, 3, 17, 2, 15, 10, 6),
 ##     factors = factors, col = "#EEEEEE", font = 2,
 ##     direction = "horizontal")
 ## circos.trackPlotRegion(ylim = c(0, 1), factors = factors,
-##     bg.col = rep(c("#E41A1C", "#4DAF4A"), 10), bg.border = "#EEEEEE",
+##     bg.col = rep(c("#E41A1C", "#4DAF4A"), 10), bg.border = "#EEEEEE", 
 ##     track.height = 0.05)
 ## circos.trackPlotRegion(ylim = c(0, 1), factors = factors,
-##     bg.col = rep(c("black", "white"), 10), bg.border = "#EEEEEE",
+##     bg.col = rep(c("black", "white"), 10), bg.border = "#EEEEEE", 
 ##     track.height = 0.275)
 ## circos.trackPlotRegion(ylim = c(0, 1), factors = factors,
 ##     bg.col = rep(c("#E41A1C", "#4DAF4A"), 10), bg.border = "#EEEEEE",
@@ -85,18 +80,17 @@ par(mar = c(1, 1, 1, 1))
 circos.par("gap.degree" = 0, "cell.padding" = c(0, 0, 0, 0),
     start.degree = 360/40, track.margin = c(0, 0), "clock.wise" = FALSE)
 circos.initialize(factors = factors, xlim = c(0, 1))
-circos.trackPlotRegion(ylim = c(0, 1), factors = factors,
-    bg.col = "black", track.height = 0.15)
+circos.trackPlotRegion(ylim = c(0, 1), factors = factors, bg.col = "black",
+    track.height = 0.15)
 circos.trackText(rep(0.5, 20), rep(0.5, 20),
-    labels = c(13, 4, 18, 1, 20, 5, 12, 9, 14, 11,
-        8, 16, 7, 19, 3, 17, 2, 15, 10, 6),
+    labels = c(13, 4, 18, 1, 20, 5, 12, 9, 14, 11, 8, 16, 7, 19, 3, 17, 2, 15, 10, 6),
     factors = factors, col = "#EEEEEE", font = 2,
     direction = "horizontal")
 circos.trackPlotRegion(ylim = c(0, 1), factors = factors,
-    bg.col = rep(c("#E41A1C", "#4DAF4A"), 10), bg.border = "#EEEEEE",
+    bg.col = rep(c("#E41A1C", "#4DAF4A"), 10), bg.border = "#EEEEEE", 
     track.height = 0.05)
 circos.trackPlotRegion(ylim = c(0, 1), factors = factors,
-    bg.col = rep(c("black", "white"), 10), bg.border = "#EEEEEE",
+    bg.col = rep(c("black", "white"), 10), bg.border = "#EEEEEE", 
     track.height = 0.275)
 circos.trackPlotRegion(ylim = c(0, 1), factors = factors,
     bg.col = rep(c("#E41A1C", "#4DAF4A"), 10), bg.border = "#EEEEEE",
@@ -118,7 +112,7 @@ circos.clear()
 ## library(circlize)
 ## factors = letters[1:8]
 ## par(mar = c(1, 1, 1, 1))
-## circos.par("default.track.height" = 0.15, "start.degree" = 22.5)
+## circos.par("default.track.height" = 0.15, "start.degree" = 22.5, "gap.degree" = 6)
 ## circos.initialize(factors = factors, xlim = c(0, 1))
 ## 
 ## circos.trackPlotRegion(ylim = c(0, 1), factors = factors, bg.border = NA,
@@ -177,7 +171,7 @@ circos.clear()
 library(circlize)
 factors = letters[1:8]
 par(mar = c(1, 1, 1, 1))
-circos.par("default.track.height" = 0.15, "start.degree" = 22.5)
+circos.par("default.track.height" = 0.15, "start.degree" = 22.5, "gap.degree" = 6)
 circos.initialize(factors = factors, xlim = c(0, 1))
 
 circos.trackPlotRegion(ylim = c(0, 1), factors = factors, bg.border = NA,
